<?php

namespace Drupal\image_utilities\Twig\Extension;

use Drupal\image_utilities\ImageManagerInterface;
use Twig\Extension\AbstractExtension;
use Twig\TwigFilter;

/**
 * A Twig extending for building image urls.
 */
class ImageStyleExtension extends AbstractExtension {

  /**
   * The image manager.
   *
   * @var \Drupal\image_utilities\ImageManagerInterface
   */
  protected $imageManager;

  /**
   * ImageStyleExtension constructor.
   *
   * @param \Drupal\image_utilities\ImageManagerInterface $image_manager
   *   The image manager.
   */
  public function __construct(ImageManagerInterface $image_manager) {
    $this->imageManager = $image_manager;
  }

  /**
   * {@inheritdoc}
   */
  public function getFilters(): array {
    return [
      new TwigFilter('image_style', [$this, 'applyImageStyle']),
    ];
  }

  /**
   * Get the image url for the incoming file object, with a certain image style.
   */
  public function applyImageStyle($file, string $style, bool $relative = TRUE, bool $directUrlIfNotSupported = FALSE): ?string {
    // @todo Dispatch cache metadata
    $url = $this->imageManager->getImageUrlByAnyObject($file, $style, $directUrlIfNotSupported);

    if ($url && $relative) {
      return file_url_transform_relative($url);
    }

    return $url;
  }

}
